==> openGion7.2.8.0_dev.zip: uap/webapps/ge/db/FIREBIRD/sql/install/01_TABLE/GE50S.sql <==
/****************************************************************************/
/* GE50 ( 帳票要求ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2018/09/28 16:03:35                                            */
/****************************************************************************/

CREATE TABLE GE50 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID       */
 , YKNO         INTEGER             DEFAULT 0   NOT NULL            /*  20 要求NO       */
 , GROUPID      VARCHAR (  10 )                                     /*  30 ｸﾞﾙｰﾌﾟID     */
 , LISTID       VARCHAR (  10 )                 NOT NULL            /*  40 帳票ID       */
 , JOKEN        VARCHAR (  20 )                 NOT NULL            /*  50 振分条件     */
 , FGKAN        VARCHAR (   1 )                 NOT NULL            /*  60 完成ﾌﾗｸﾞ     */
 , OUT_DIR      VARCHAR ( 100 )                                     /*  70 出力ﾌｧｲﾙDIR  */
 , OUT_FILE     VARCHAR (  50 )                                     /*  80 出力ﾌｧｲﾙ名   */
 , COMMENTS     VARCHAR ( 500 )                                     /*  90 ｺﾒﾝﾄ         */
 , SUDATA       INTEGER             DEFAULT 0   NOT NULL            /* 100 ﾃﾞｰﾀ件数     */
 , SUPAGE       INTEGER             DEFAULT 0   NOT NULL            /* 110 ﾍﾟｰｼﾞ数      */
 , DMN_NAME     VARCHAR (  20 )                                     /* 120 更新ﾃﾞｰﾓﾝ名  */
 , DMN_HOST     VARCHAR (  50 )                                     /* 130 ﾃﾞｰﾓﾝﾎｽﾄ     */
 , PDF_PASSWD   VARCHAR (  20 )                                     /* 140 PDFﾊﾟｽﾜｰﾄﾞ   */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (  14 )                                     /* 820 登録日時     */
 , PGSET        VARCHAR (  10 )                                     /* 830 作成PG       */
 , PGPSET       VARCHAR (  10 )                                     /* 840 作成親PG     */
 , USRSET       VARCHAR (  10 )                                     /* 850 作成者       */
 , DYUPD        VARCHAR (  14 )                                     /* 860 更新日時     */
 , PGUPD        VARCHAR (  10 )                                     /* 870 更新PG       */
 , PGPUPD       VARCHAR (  10 )                                     /* 880 更新親PG     */
 , USRUPD       VARCHAR (  10 )                                     /* 890 更新者       */
);

==> openGion7.4.0.0_dev.zip: uap/webapps/ge/db/FIREBIRD/sql/install/01_TABLE/GE50S.sql <==
/****************************************************************************/
/* GE50 ( 帳票要求ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2020/12/16 08:14:13                                            */
/****************************************************************************/

CREATE TABLE GE50 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID       */
 , YKNO         INTEGER             DEFAULT 0   NOT NULL            /*  20 要求NO       */
 , GROUPID      VARCHAR (  10 )                                     /*  30 ｸﾞﾙｰﾌﾟID     */
 , LISTID       VARCHAR (  10 )                 NOT NULL            /*  40 帳票ID       */
 , JOKEN        VARCHAR (  20 )                 NOT NULL            /*  50 振分条件     */
 , FGKAN        VARCHAR (   1 )                 NOT NULL            /*  60 完成ﾌﾗｸﾞ     */
 , OUT_DIR      VARCHAR ( 100 )                                     /*  70 出力ﾌｧｲﾙDIR  */
 , OUT_FILE     VARCHAR (  50 )                                     /*  80 出力ﾌｧｲﾙ名   */
 , COMMENTS     VARCHAR ( 500 )                                     /*  90 ｺﾒﾝﾄ         */
 , SUDATA       INTEGER             DEFAULT 0   NOT NULL            /* 100 ﾃﾞｰﾀ件数     */
 , SUPAGE       INTEGER             DEFAULT 0   NOT NULL            /* 110 ﾍﾟｰｼﾞ数      */
 , DMN_NAME     VARCHAR (  20 )                                     /* 120 更新ﾃﾞｰﾓﾝ名  */
 , DMN_HOST     VARCHAR (  50 )                                     /* 130 ﾃﾞｰﾓﾝﾎｽﾄ     */
 , PDF_PASSWD   VARCHAR (  20 )                                     /* 140 PDFﾊﾟｽﾜｰﾄﾞ   */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (  14 )                                     /* 820 作成日時     */
 , PGSET        VARCHAR (  10 )                                     /* 830 作成PG       */
 , PGPSET       VARCHAR (  10 )                                     /* 840 作成親PG     */
 , USRSET       VARCHAR (  10 )                                     /* 850 作成者       */
 , DYUPD        VARCHAR (  14 )                                     /* 860 更新日時     */
 , PGUPD        VARCHAR (  10 )                                     /* 870 更新PG       */
 , PGPUPD       VARCHAR (  10 )                                     /* 880 更新親PG     */
 , USRUPD       VARCHAR (  10 )                                     /* 890 更新者       */
);
